@@ -212,7 +212,7 @@ sp.sums.2 <- function( x,
                       log.breaks=c(2,5,12,18,32,999),
                       log.grades=c("pulp","s4","s3","s2","s1","peeler") ) {
 
-  if( class( x ) != "sample.data" ) {
+  if( !("sample.data" %in% class( x )) ) {
     stop( "Error: x is not a sample.data object." )
   }
 
