@@ -1,6 +1,6 @@
 show.cols.with.na <-
 function(x) {
-  if (class(x) != "data.frame") 
+  if (!(is.data.frame(x)))
     stop("x must be a dataframe.\n")
   missing.by.column <- apply(is.na(x), 2, sum)
   if (sum(missing.by.column) == 0) {
